@@ -2,12 +2,13 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this file,
 # You can obtain one at http://mozilla.org/MPL/2.0/.
 #
-# Copyright (c) 2014-2021, Lars Asplund lars.anders.asplund@gmail.com
+# Copyright (c) 2014-2023, Lars Asplund lars.anders.asplund@gmail.com
 
 """
 json4vhdl helper functions
 """
 
+from pathlib import Path
 from typing import Union
 import json
 from base64 import b16encode as b16enc
@@ -40,7 +41,8 @@ def read_json(filename: str):
 
        generics = read_json(join(root, "src/test/data/data.json"))
     """
-    return json.loads(open(filename, "r").read())
+    with Path(filename).open("r", encoding="utf-8") as fptr:
+        return json.loads(fptr.read())
 
 
 def b16encode(data: Union[str, bytes]):
